Crate kcr_ptp_openshift_io

Crate kcr_ptp_openshift_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the ptp.openshift.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

ptp.openshift.io/v1

  • NodePtpDevice
  • PtpConfig
  • PtpOperatorConfig

Modules

v1